summaryrefslogtreecommitdiffstats
path: root/pkg/commands/git.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/commands/git.go')
-rw-r--r--pkg/commands/git.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/pkg/commands/git.go b/pkg/commands/git.go
index 08eb78edf..ab71f80e3 100644
--- a/pkg/commands/git.go
+++ b/pkg/commands/git.go
@@ -265,7 +265,7 @@ func includesInt(list []int, a int) bool {
// ResetAndClean removes all unstaged changes and removes all untracked files
func (c *GitCommand) ResetAndClean() error {
- if err := c.ResetHardHead(); err != nil {
+ if err := c.ResetHard("HEAD"); err != nil {
return err
}
@@ -961,14 +961,14 @@ func (c *GitCommand) RemoveUntrackedFiles() error {
return c.OSCommand.RunCommand("git clean -fd")
}
-// ResetHardHead runs `git reset --hard HEAD`
-func (c *GitCommand) ResetHardHead() error {
- return c.OSCommand.RunCommand("git reset --hard HEAD")
+// ResetHardHead runs `git reset --hard`
+func (c *GitCommand) ResetHard(ref string) error {
+ return c.OSCommand.RunCommand("git reset --hard " + ref)
}
-// ResetSoftHead runs `git reset --soft HEAD`
-func (c *GitCommand) ResetSoftHead() error {
- return c.OSCommand.RunCommand("git reset --soft HEAD")
+// ResetSoft runs `git reset --soft HEAD`
+func (c *GitCommand) ResetSoft(ref string) error {
+ return c.OSCommand.RunCommand("git reset --soft " + ref)
}
// DiffCommits show diff between commits